@@ -1,3 +1,4 @@
+use crate::error::BindError;
 use std::net::{SocketAddr, UdpSocket};
 use std::time::Duration;
 
@@ -6,17 +7,10 @@ pub struct Socket {
 }
 
 impl Socket {
-    pub fn create_udp_socket(host: String) -> UdpSocket {
-        UdpSocket::bind(host).expect("failed to bind host socket")
-    }
-    pub fn new(host: String) -> Self {
-        Self {
-            socket: Socket::create_udp_socket(host),
-        }
-    }
-
-    fn get_duration(&self) -> Option<Duration> {
-        std::option::Option::Some(Duration::new(100, 0))
+    pub fn new(host: String) -> Result<Self, BindError> {
+        Ok(Self {
+            socket: UdpSocket::bind(host)?,
+        })
     }
 
     pub fn set_write_timeout(&self, duration: Option<Duration>) -> std::io::Result<()> {
@@ -27,10 +21,6 @@ impl Socket {
         self.socket.set_read_timeout(duration)
     }
 
-    pub fn set_duration(&self) -> std::io::Result<()> {
-        self.socket.set_write_timeout(self.get_duration())
-    }
-
     pub fn send_to(&self, message: &[u8], receiver: String) -> std::io::Result<usize> {
         self.socket.send_to(message, receiver)
     }
